
.. image:: _static/silex-192x192.png
    :align: center

Welcome to OpenCobolIDE documentation!
==========================================

OpenCobolIDE is a simple and lightweight COBOL IDE based on the
`OpenCOBOL/GnuCOBOL`_ compiler and the `pyQode`_ source code editor widget.


Parts of the documentation:
===========================

.. toctree::
    :maxdepth: 1
    :hidden:

    whats_new
    download
    getting_started
    settings
    advanced
    tipsandtricks
    faq
    contribute
    license


.. hlist::
   :columns: 1

   * .. glossary::

      :doc:`whats_new`
         What's new since the last release, and what is planned for the next one.

   * .. glossary::

      :doc:`download`
         Instructions on where and how to install OpenCobolIDE.

   * .. glossary::

      :doc:`getting_started`
         Getting started with OpenCobolIDE

   * .. glossary::

      :doc:`settings`
         Description of the application preferences settings

   * .. glossary::

      :doc:`advanced`
         Covers some more advanced topics

   * .. glossary::

      :doc:`tipsandtricks`
         Tips & Tricks

   * .. glossary::

      :doc:`faq`
         Frequently asked questions


Meta information:
=================

.. hlist::
   :columns: 2

   * .. glossary::

      :doc:`contribute`
        How to contribute and report bugs

   * .. glossary::

      :doc:`license`
        OpenCobolIDE license


Indices and tables:
===================

* :ref:`genindex`

* :ref:`search`


.. _pyQode: https://github.com/pyQode
.. _OpenCOBOL/GnuCOBOL: http://sourceforge.net/projects/open-cobol/
